pub struct CrossSigningSecrets {
pub master_key: String,
pub user_signing_key: String,
pub self_signing_key: String,
}Expand description
Data for the secrets bundle containing the cross-signing keys.
Fields
master_key: StringThe seed for the private part of the cross-signing master key, encoded as base64.
user_signing_key: StringThe seed for the private part of the cross-signing user-signing key, encoded as base64.
self_signing_key: StringThe seed for the private part of the cross-signing self-signing key, encoded as base64.