pub trait RoomKeyExport {
// Required methods
fn room_id(&self) -> &RoomId;
fn session_id(&self) -> &str;
fn sender_key(&self) -> Curve25519PublicKey;
}Expand description
Trait to express the various room key export formats we have in a unified manner.
Required Methods
Sourcefn session_id(&self) -> &str
fn session_id(&self) -> &str
The unique ID of the exported room key.
Sourcefn sender_key(&self) -> Curve25519PublicKey
fn sender_key(&self) -> Curve25519PublicKey
The Curve25519PublicKey long-term identity key of the sender of this room key.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".